@@ -205,26 +205,30 @@ class Manager(object):
         Emisor = SubElement(Encabezado, "Emisor")
         SubElement(Emisor, "RUCEmisor").text = str(self.emisor.vat.number or '')
         SubElement(Emisor, "RznSoc").text = str(self.emisor.name)
+        if hasattr(self.emisor, 'phone'): SubElement(Emisor, "Telefono").text = str(self.emisor.phone)
+        if hasattr(self.emisor, 'email'): SubElement(Emisor, "CorreoEmisor").text = str(self.emisor.email)
         SubElement(Emisor, "CdgDGISucur").text = str(self.connection_data.sucursal_code or '')
         SubElement(Emisor, "DomFiscal").text = str(self.emisor.street or '')
         SubElement(Emisor, "Ciudad").text = str(self.emisor.city or '')
         SubElement(Emisor, "Departamento").text = str(self.emisor.state or '')
 
     def build_Receptor(self, Encabezado, type):
-
+        
         Receptor = SubElement(Encabezado, "Receptor")
 
         RECEPTOR_BUILDER = {
             'eFact_Exp': self.build_exportation_receptor,
             'eFact': self.build_local_receptor,
-            'eTck': self.build_local_receptor,
+            'eTck': self.build_local_receptor_etck,
             'eBoleta': self.build_local_receptor,
             'eResg': self.build_local_receptor,
             'eRem': self.build_local_receptor_rem,
             'eRem_Exp': self.build_exportation_receptor,
-        }
-
-        RECEPTOR_BUILDER.get(type)(Receptor)
+        }          
+        if type == 'eTck':
+            RECEPTOR_BUILDER.get(type)(Receptor,Encabezado)
+        else:
+            RECEPTOR_BUILDER.get(type)(Receptor)
 
     def get_doc_recep_type(self, country_code):
         return "DocRecep" if country_code == LOCAL_COUNTRY_CODE else "DocRecepExt"
@@ -243,8 +247,21 @@ class Manager(object):
             SubElement(Receptor, "CompraID").text = str(self.comprobante.identificator or '')
         if self.comprobante.partner.zip: SubElement(Receptor, "CP").text = str(self.comprobante.partner.zip or '')
 
-    def build_local_receptor(self, Receptor):
+    def build_local_receptor_etck(self, Receptor, Encabezado):
+        """
+        Completa los datos del receptor de un eTicket 
+        solo si tienen datos de tipo y número de documento.
+        Si no están esos datos se quita el tag del Receptor. 
+        :param Receptor: elemento Receptor del xml
+        :param Encabezado: elemento Encabezado del xml
+        """
+        if self.comprobante.partner.vat:
+            self.build_local_receptor(Receptor)
+        else:
+            Encabezado.remove(Receptor)
 
+    def build_local_receptor(self, Receptor):
+        
         SubElement(Receptor, "TipoDocRecep").text = str(self.comprobante.partner.vat.code or '')
         SubElement(Receptor, "CodPaisRecep").text = str(self.comprobante.partner.country_code or '')
         SubElement(Receptor, self.get_doc_recep_type(self.comprobante.partner.country_code)).text = str(self.comprobante.partner.vat.number or '')
@@ -310,7 +327,7 @@ class Manager(object):
         if self.get_mnt_iva_tasa_basic(): SubElement(Totales, "MntIVATasaBasica").text = self._format_amount(self.get_mnt_iva_tasa_basic())
         SubElement(Totales, "MntTotal").text = self._format_amount(self.get_total_amount())
         SubElement(Totales, "CantLinDet").text = str(len(self.comprobante.invoice_lines))
-        if self.get_mnt_non_invoiceable(): SubElement(Totales, "MontoNF").text = self._format_amount(self.get_mnt_non_invoiceable())
+        if self.get_mnt_non_invoiceable() or self.get_mnt_negative_non_invoiceable(): SubElement(Totales, "MontoNF").text = self._format_amount(self.get_mnt_non_invoiceable() + self.get_mnt_negative_non_invoiceable())
         SubElement(Totales, "MntPagar").text = self._format_amount(self.get_total_to_pay())
 
     def totales_eResg(self, Totales):
@@ -367,7 +384,7 @@ class Manager(object):
                     SubElement(ReferenciaChild, "Serie").text = refund.cfe_serial
                     SubElement(ReferenciaChild, "NroCFERef").text = refund.cfe_number
                     SubElement(ReferenciaChild, "RazonRef").text = reference_details.refund_reason or 'N/A'
-                    SubElement(ReferenciaChild, "FechaCFEref").text = refund.date
+                    SubElement(ReferenciaChild, "FechaCFEref").text = str(refund.date)
 
             else:
 
@@ -455,7 +472,7 @@ class Manager(object):
             if hasattr(line, 'discount') and hasattr(line, 'discount_amount'):
                 SubElement(Item[item_nro], "DescuentoPct").text = self._format_amount(line.discount)
                 SubElement(Item[item_nro], "DescuentoMonto").text = self._format_amount(line.discount_amount)
-            SubElement(Item[item_nro], "MontoItem").text = self._format_amount(line.amount)
+            SubElement(Item[item_nro], "MontoItem").text = self._format_amount(abs(line.amount))
 
     def detalle_eResg(self, Detalle):
 
@@ -512,10 +529,7 @@ class Manager(object):
         return total - tax_discount if total else 0
 
     def get_mnt_base(self, indicator):
-        if self.comprobante.include_tax:
-            total = sum([line.amount - line.tax for line in self.comprobante.invoice_lines if str(line.invoice_indicator) == str(indicator)])
-        else:
-            total = sum([line.amount for line in self.comprobante.invoice_lines if str(line.invoice_indicator) == str(indicator)])
+        total = sum([line.amount - line.tax if line.include_tax else line.amount for line in self.comprobante.invoice_lines if str(line.invoice_indicator) == str(indicator)])
         total_discount = sum([line_discount.amount for line_discount in self.comprobante.invoice_discount_lines if
                               str(line_discount.invoice_indicator) == str(indicator)]) if\
             hasattr(self.comprobante,'invoice_discount_lines') else 0
@@ -524,6 +538,9 @@ class Manager(object):
     def get_mnt_non_invoiceable(self):
         return self.get_mnt(INVOICE_INDICATOR.get('no_invoiceable'))
 
+    def get_mnt_negative_non_invoiceable(self):
+        return self.get_mnt(INVOICE_INDICATOR.get('negative_no_invoiceable'))
+
     def get_mnt_non_taxable(self):
         return self.get_mnt(INVOICE_INDICATOR.get('no_taxable'))
 
@@ -554,7 +571,7 @@ class Manager(object):
         return total_basic + total_min + total_no_taxable + total_exempt + total_exportation
 
     def get_total_to_pay(self):
-        return self.get_total_amount() + self.get_mnt_non_invoiceable()
+        return self.get_total_amount() + self.get_mnt_non_invoiceable() + self.get_mnt_negative_non_invoiceable()
 
     def get_total_retention(self):
         return sum([ret.get_amount() for ret in self.comprobante.retentions])
